# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%global cvs_version 2_7_2

Name:           xalan-j2
Version:        2.7.2
Release:        %mkrel 3
Group:          Development/Java
Epoch:          0
Summary:        Java XSLT processor
# src/org/apache/xpath/domapi/XPathStylesheetDOM3Exception.java is W3C
License:        ASL 2.0 and W3C
URL:            http://xalan.apache.org/

# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}-serializer-MANIFEST.MF
Source2:        http://repo1.maven.org/maven2/xalan/xalan/%{version}/xalan-%{version}.pom
Source3:        http://repo1.maven.org/maven2/xalan/serializer/%{version}/serializer-%{version}.pom
Source4:        xsltc-%{version}.pom
Source5:        %{name}-MANIFEST.MF
# Remove bundled binaries which cannot be easily verified for licensing
Source6:        generate-tarball.sh

Patch0:         %{name}-noxsltcdeps.patch

BuildArch:      noarch

BuildRequires:  javapackages-local
BuildRequires:  ant
BuildRequires:  apache-parent
BuildRequires:  bcel
BuildRequires:  java_cup
BuildRequires:  regexp
BuildRequires:  sed
BuildRequires:  glassfish-servlet-api
BuildRequires:  xerces-j2 >= 0:2.7.1
BuildRequires:  xml-commons-apis >= 0:1.3
BuildRequires:  java-1.8.0-openjdk-devel

Requires:       xerces-j2

Provides:       jaxp_transform_impl

%description
Xalan is an XSLT processor for transforming XML documents into HTML,
text, or other XML document types. It implements the W3C Recommendations
for XSL Transformations (XSLT) and the XML Path Language (XPath). It can
be used from the command line, in an applet or a servlet, or as a module
in other program.

%package        xsltc
Summary:        XSLT compiler
License:        ASL 2.0
Requires:       java_cup
Requires:       bcel
Requires:       regexp
Requires:       xerces-j2

%description    xsltc
The XSLT Compiler is a Java-based tool for compiling XSLT stylesheets into
lightweight and portable Java byte codes called translets.

%package        manual
Summary:        Manual for %{name}
License:        ASL 2.0

%description    manual
Documentation for %{name}.

%package        javadoc
Summary:        Javadoc for %{name}
License:        ASL 2.0

%description    javadoc
Javadoc for %{name}.

%package        demo
Summary:        Demo for %{name}
License:        ASL 2.0
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       glassfish-servlet-api

%description    demo
Demonstrations and samples for %{name}.

%prep
%setup -q -n xalan-j_%{cvs_version}
%patch0 -p0

find . -name '*.jar' -delete
find . -name '*.class' -delete

sed -i '/<!-- Expand jaxp sources/,/<delete file="${xml-commons-srcs.tar}"/{d}' build.xml

# Remove classpaths from manifests
sed -i '/class-path/I d' $(find -iname '*manifest*')

# Convert CR-LF to LF-only
sed -i 's/\r//' KEYS LICENSE.txt NOTICE.txt xdocs/style/resources/script.js \
    xdocs/sources/xsltc/README* `find -name '*.sh'`

%mvn_file :xalan %{name} jaxp_transform_impl
%mvn_file :serializer %{name}-serializer
%mvn_file :xsltc xsltc
%mvn_package :xsltc xsltc

%build
export JAVA_HOME=%{_jvmdir}/java-1.8.0-openjdk
pushd lib
ln -sf $(build-classpath java_cup-runtime) runtime.jar
ln -sf $(build-classpath bcel) BCEL.jar
ln -sf $(build-classpath regexp) regexp.jar
ln -sf $(build-classpath xerces-j2) xercesImpl.jar
ln -sf $(build-classpath xml-commons-apis) xml-apis.jar
popd
pushd tools
ln -sf $(build-classpath java_cup) java_cup.jar
ln -sf $(build-classpath ant) ant.jar
popd
export CLASSPATH=$(build-classpath glassfish-servlet-api)

ant -Dcompiler.source=1.8 -Dcompiler.target=1.8 \
  -Djava.awt.headless=true \
  -Dapi.j2se=%{_javadocdir}/java \
  -Dbuild.xalan-interpretive.jar=build/xalan-interpretive.jar \
  xalan-interpretive.jar\
  xsltc.unbundledjar \
  docs \
  javadocs \
  samples \
  servlet

# inject OSGi manifests
jar ufm build/serializer.jar %{SOURCE1}
jar ufm build/xalan-interpretive.jar %{SOURCE5}

%mvn_artifact %{SOURCE2} build/xalan-interpretive.jar
%mvn_artifact %{SOURCE3} build/serializer.jar
%mvn_artifact %{SOURCE4} build/xsltc.jar

%install
%mvn_install -J build/docs/apidocs

# demo
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}
install -p -m 644 build/xalansamples.jar \
  $RPM_BUILD_ROOT%{_datadir}/%{name}/%{name}-samples.jar
install -p -m 644 build/xalanservlet.war \
  $RPM_BUILD_ROOT%{_datadir}/%{name}/%{name}-servlet.war
cp -pr samples $RPM_BUILD_ROOT%{_datadir}/%{name}

# fix link between manual and javadoc
(cd build/docs; ln -sf %{_javadocdir}/%{name} apidocs)

%post
# update-alternatives will remove the symlink - preserve it
mv %{_javadir}/jaxp_transform_impl.jar{,.tmp} || :
# alternatives removed in f26
update-alternatives --remove jaxp_transform_impl %{_javadir}/%{name}.jar &>/dev/null || :
# restore the symlink
mv %{_javadir}/jaxp_transform_impl.jar{.tmp,} || :

%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc KEYS readme.html

%files xsltc -f .mfiles-xsltc
%license LICENSE.txt NOTICE.txt

%files manual
%license LICENSE.txt NOTICE.txt
%doc build/docs/*

%files javadoc
%license LICENSE.txt NOTICE.txt
%doc %{_javadocdir}/%{name}

%files demo
%{_datadir}/%{name}



%changelog
* Tue Oct 27 2020 tv <tv> 0:2.7.2-3.mga8
+ Revision: 1639819
- Peg to Java 8 due to build issues on Java 11

* Thu Feb 20 2020 umeabot <umeabot> 0:2.7.2-2.mga8
+ Revision: 1547361
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 daviddavid <daviddavid> 0:2.7.2-1.mga8
+ Revision: 1487997
- new version: 2.7.2

* Wed Dec 05 2018 daviddavid <daviddavid> 0:2.7.1-35.mga7
+ Revision: 1338543
- Update license of subpackages
- Remove BR on xml-stylebook
- Repack the tarball without binaries

* Fri Sep 21 2018 umeabot <umeabot> 0:2.7.1-34.mga7
+ Revision: 1292158
- Mageia 7 Mass Rebuild

* Fri Sep 29 2017 daviddavid <daviddavid> 0:2.7.1-33.mga7
+ Revision: 1161723
- Build against glassfish-servlet-api
- Install with XMvn
- Remove alternatives
- Fix missing jaxp_transformer_impl symlink after upgrade
- Elimitate race condition when injecting JAR manifest
- Resolves: rhbz#1495250
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 0:2.7.1-28.mga6
+ Revision: 978573
- First rebuild of the java stack
- sync package xalan-j2 with fedora

* Tue Feb 09 2016 umeabot <umeabot> 0:2.7.1-11.mga6
+ Revision: 951563
- Mageia 6 Mass Rebuild

* Sat Jan 03 2015 daviddavid <daviddavid> 0:2.7.1-10.mga5
+ Revision: 808266
- convert CR-LF to LF with dos2unix
- Sync with fc21 (fix build failure)

* Wed Oct 15 2014 umeabot <umeabot> 0:2.7.1-9.mga5
+ Revision: 740045
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:2.7.1-8.mga5
+ Revision: 690537
- Mageia 5 Mass Rebuild

* Tue Apr 01 2014 luigiwalser <luigiwalser> 0:2.7.1-7.mga5
+ Revision: 611012
- add patch from debian to fix CVE-2014-0107

* Fri Oct 18 2013 umeabot <umeabot> 0:2.7.1-6.mga4
+ Revision: 520379
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 0:2.7.1-5.mga3
+ Revision: 386409
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 0:2.7.1-4.mga3
+ Revision: 324915
- Java stack Mass Rebuild

* Sat Dec 17 2011 gil <gil> 0:2.7.1-3.mga2
+ Revision: 183018
- build fix
  added BR zip
- build fix
  added maven poms

* Thu Apr 28 2011 dmorgan <dmorgan> 0:2.7.1-2.mga1
+ Revision: 93150
- Rebuild after bootstrapping
- imported package xalan-j2

